/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef, Component, EventEmitter, Input, Output } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { AriaLabelValueDirective } from '../aria-label.directive';
import { DropDownListComponent } from '@progress/kendo-angular-dropdowns';
import * as i0 from "@angular/core";
import * as i1 from "@progress/kendo-angular-l10n";
/**
 * @hidden
 */
export class FilterBooleanEditorComponent {
    localization;
    cdr;
    currentItem;
    valueChange = new EventEmitter();
    items;
    defaultItem;
    localizationSubscription;
    constructor(localization, cdr) {
        this.localization = localization;
        this.cdr = cdr;
    }
    ngOnInit() {
        this.localizationSubscription = this.localization.changes.subscribe(() => {
            this.defaultItem = this.getDefaultItem();
            this.items = this.getValueItems();
            this.cdr.detectChanges();
        });
        this.items = this.getValueItems();
        this.defaultItem = this.getDefaultItem();
    }
    getDefaultItem() {
        return { text: this.localization.get("filterBooleanAll"), value: null };
    }
    getValueItems() {
        return [
            { text: this.localization.get("filterIsTrue"), value: true },
            { text: this.localization.get("filterIsFalse"), value: false }
        ];
    }
    ngOnDestroy() {
        if (this.localizationSubscription) {
            this.localizationSubscription.unsubscribe();
        }
    }
    messageFor(key) {
        return this.localization.get(key);
    }
    onValueChange(value) {
        this.currentItem.value = value;
        this.valueChange.emit();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterBooleanEditorComponent, deps: [{ token: i1.LocalizationService }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: FilterBooleanEditorComponent, isStandalone: true, selector: "kendo-filter-boolean-editor", inputs: { currentItem: "currentItem" }, outputs: { valueChange: "valueChange" }, ngImport: i0, template: `
    <kendo-dropdownlist
        [tabindex]="-1"
        [kendoAriaLabelValue]="messageFor('filterValueAriaLabel')"
        [value]="currentItem.value"
        (valueChange)="onValueChange($event)"
        [data]="items"
        [defaultItem]="defaultItem"
        [valuePrimitive]="true"
        textField="text"
        valueField="value"
        >
    </kendo-dropdownlist>
  `, isInline: true, dependencies: [{ kind: "component", type: DropDownListComponent, selector: "kendo-dropdownlist", inputs: ["customIconClass", "showStickyHeader", "icon", "svgIcon", "loading", "data", "value", "textField", "valueField", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "defaultItem", "disabled", "itemDisabled", "readonly", "filterable", "virtual", "ignoreCase", "delay", "valuePrimitive", "tabindex", "tabIndex", "size", "rounded", "fillMode", "leftRightArrowsNavigation", "id"], outputs: ["valueChange", "filterChange", "selectionChange", "open", "opened", "close", "closed", "focus", "blur"], exportAs: ["kendoDropDownList"] }, { kind: "directive", type: AriaLabelValueDirective, selector: "[kendoAriaLabelValue]", inputs: ["kendoAriaLabelValue"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterBooleanEditorComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-filter-boolean-editor',
                    template: `
    <kendo-dropdownlist
        [tabindex]="-1"
        [kendoAriaLabelValue]="messageFor('filterValueAriaLabel')"
        [value]="currentItem.value"
        (valueChange)="onValueChange($event)"
        [data]="items"
        [defaultItem]="defaultItem"
        [valuePrimitive]="true"
        textField="text"
        valueField="value"
        >
    </kendo-dropdownlist>
  `,
                    standalone: true,
                    imports: [DropDownListComponent, AriaLabelValueDirective]
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { currentItem: [{
                type: Input
            }], valueChange: [{
                type: Output
            }] } });
