/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Component, EventEmitter, Input, Output } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { defaultOperators, getKeyByValue } from './util';
import { DropDownListComponent, ItemTemplateDirective, ValueTemplateDirective } from '@progress/kendo-angular-dropdowns';
import { AriaLabelValueDirective } from './aria-label.directive';
import * as i0 from "@angular/core";
import * as i1 from "@progress/kendo-angular-l10n";
/**
 * @hidden
 */
export class FilterExpressionOperatorsComponent {
    localization;
    currentItem;
    editorType;
    valueChange = new EventEmitter();
    operators = [];
    constructor(localization) {
        this.localization = localization;
    }
    messageFor(key) {
        return this.localization.get(key);
    }
    getOperator(operatorValue) {
        return this.messageFor(getKeyByValue(defaultOperators[this.editorType], operatorValue));
    }
    operatorValueChange(value) {
        this.valueChange.emit(value);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterExpressionOperatorsComponent, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: FilterExpressionOperatorsComponent, isStandalone: true, selector: "kendo-filter-expression-operators", inputs: { currentItem: "currentItem", editorType: "editorType", operators: "operators" }, outputs: { valueChange: "valueChange" }, ngImport: i0, template: `
        <kendo-dropdownlist
            [tabindex]="-1"
            [kendoAriaLabelValue]="messageFor('filterOperatorAriaLabel')"
            [data]="operators"
            [title]="messageFor('filterExpressionOperators')"
            [(value)]="currentItem.operator"
            (valueChange)="operatorValueChange($event)"
            [valuePrimitive]="true"
            textField="text"
            valueField="value"
        >
            <ng-template kendoDropDownListValueTemplate let-dataItem>
                <span>{{ getOperator(dataItem.value) }}</span>
            </ng-template>
            <ng-template kendoDropDownListItemTemplate let-dataItem>
                <span>{{ getOperator(dataItem.value) }}</span>
            </ng-template>
        </kendo-dropdownlist>
    `, isInline: true, dependencies: [{ kind: "component", type: DropDownListComponent, selector: "kendo-dropdownlist", inputs: ["customIconClass", "showStickyHeader", "icon", "svgIcon", "loading", "data", "value", "textField", "valueField", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "defaultItem", "disabled", "itemDisabled", "readonly", "filterable", "virtual", "ignoreCase", "delay", "valuePrimitive", "tabindex", "tabIndex", "size", "rounded", "fillMode", "leftRightArrowsNavigation", "id"], outputs: ["valueChange", "filterChange", "selectionChange", "open", "opened", "close", "closed", "focus", "blur"], exportAs: ["kendoDropDownList"] }, { kind: "directive", type: AriaLabelValueDirective, selector: "[kendoAriaLabelValue]", inputs: ["kendoAriaLabelValue"] }, { kind: "directive", type: ValueTemplateDirective, selector: "[kendoDropDownListValueTemplate],[kendoDropDownTreeValueTemplate]" }, { kind: "directive", type: ItemTemplateDirective, selector: "[kendoDropDownListItemTemplate],[kendoComboBoxItemTemplate],[kendoAutoCompleteItemTemplate],[kendoMultiSelectItemTemplate]" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FilterExpressionOperatorsComponent, decorators: [{
            type: Component,
            args: [{
                    selector: "kendo-filter-expression-operators",
                    template: `
        <kendo-dropdownlist
            [tabindex]="-1"
            [kendoAriaLabelValue]="messageFor('filterOperatorAriaLabel')"
            [data]="operators"
            [title]="messageFor('filterExpressionOperators')"
            [(value)]="currentItem.operator"
            (valueChange)="operatorValueChange($event)"
            [valuePrimitive]="true"
            textField="text"
            valueField="value"
        >
            <ng-template kendoDropDownListValueTemplate let-dataItem>
                <span>{{ getOperator(dataItem.value) }}</span>
            </ng-template>
            <ng-template kendoDropDownListItemTemplate let-dataItem>
                <span>{{ getOperator(dataItem.value) }}</span>
            </ng-template>
        </kendo-dropdownlist>
    `,
                    standalone: true,
                    imports: [DropDownListComponent, AriaLabelValueDirective, ValueTemplateDirective, ItemTemplateDirective]
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; }, propDecorators: { currentItem: [{
                type: Input
            }], editorType: [{
                type: Input
            }], valueChange: [{
                type: Output
            }], operators: [{
                type: Input
            }] } });
