/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef, ElementRef, OnDestroy, OnInit, Renderer2, TemplateRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { CompositeFilterDescriptor, FilterDescriptor } from '@progress/kendo-data-query';
import { SVGIcon } from '@progress/kendo-svg-icons';
import { BaseFilterRowComponent } from './base-filter-row.component';
import { FilterService } from './filter.service';
import { DateFormat, FilterEditor, FilterExpression, FilterOperator, NumberFormat } from './model/filter-expression';
import { NavigationService } from './navigation.service';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class FilterExpressionComponent extends BaseFilterRowComponent implements OnInit, OnDestroy {
    private filterService;
    private cdr;
    /**
     * @hidden
     */
    xIcon: SVGIcon;
    static ngAcceptInputType_currentItem: FilterDescriptor | CompositeFilterDescriptor;
    currentItem: FilterDescriptor;
    operators: any[];
    isBoolean: boolean;
    editorType: FilterEditor;
    isEditorDisabled: boolean;
    editorTemplate: TemplateRef<any>;
    editorFormat: string | DateFormat | NumberFormat;
    private get currentFilterExpression();
    get numericEditorFormat(): string | NumberFormat;
    get dateEditorFormat(): string | DateFormat;
    private isNumberFormat;
    private isDateFormat;
    private localizationSubscription;
    constructor(filterService: FilterService, cdr: ChangeDetectorRef, element: ElementRef, navigationService: NavigationService, localization: LocalizationService, renderer: Renderer2);
    ngOnInit(): void;
    ngOnDestroy(): void;
    normalizeOperators(filterEditor: FilterEditor, operators: FilterOperator[]): {
        text: string;
        value: string;
    }[];
    getFilterExpressionByField(name: string): FilterExpression | null;
    filterValueChange(value: string): void;
    protected getDefaultOperators(operatorsType: FilterEditor): {
        text: string;
        value: string;
    }[];
    getEditorType(): FilterEditor;
    getFilters(): FilterExpression[];
    removeFilterExpression(): void;
    private setOperators;
    onOperatorChange(value: string): void;
    setEditorTemplate(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterExpressionComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FilterExpressionComponent, "kendo-filter-expression", never, { "currentItem": { "alias": "currentItem"; "required": false; }; }, {}, never, never, true, never>;
}
